@@ -15,14 +15,11 @@
 
 """A simple Set class."""
 
-
 class Set(object):
-
     """A simple set class.
 
-    Sets are not in Python until 2.3, and rdata are not immutable so
-    we cannot use sets.Set anyway.  This class implements subset of
-    the 2.3 Set interface using a list as the container.
+    This class implements a mutable set using a list as the container.
+    We don't use Python's set class because it's not indexable.
 
     @ivar items: A list of the items which are in the set
     @type items: list"""
@@ -37,7 +34,7 @@ class Set(object):
         """
 
         self.items = []
-        if items is not None:
+        if not items is None:
             for item in items:
                 self.add(item)
 
@@ -46,7 +43,7 @@ class Set(object):
 
     def add(self, item):
         """Add an item to the set."""
-        if item not in self.items:
+        if not item in self.items:
             self.items.append(item)
 
     def remove(self, item):
@@ -210,10 +207,10 @@ class Set(object):
         # Yes, this is inefficient but the sets we're dealing with are
         # usually quite small, so it shouldn't hurt too much.
         for item in self.items:
-            if item not in other.items:
+            if not item in other.items:
                 return False
         for item in other.items:
-            if item not in self.items:
+            if not item in self.items:
                 return False
         return True
 
@@ -232,6 +229,12 @@ class Set(object):
     def __delitem__(self, i):
         del self.items[i]
 
+    def __getslice__(self, i, j):
+        return self.items[i:j]
+
+    def __delslice__(self, i, j):
+        del self.items[i:j]
+
     def issubset(self, other):
         """Is I{self} a subset of I{other}?
 
@@ -241,7 +244,7 @@ class Set(object):
         if not isinstance(other, Set):
             raise ValueError('other must be a Set instance')
         for item in self.items:
-            if item not in other.items:
+            if not item in other.items:
                 return False
         return True
 
@@ -254,6 +257,6 @@ class Set(object):
         if not isinstance(other, Set):
             raise ValueError('other must be a Set instance')
         for item in other.items:
-            if item not in self.items:
+            if not item in self.items:
                 return False
         return True
