@@ -12,15 +12,15 @@
 #
 # E.g. on my systems I have this
 #
-#        #!/bin/sh
+#	#!/bin/sh
 #
-#        DEVICE=$1
+#	DEVICE=$1
 #
-#        if [ "X${DEVICE}" == "Xeth0" ]; then
-#                IPADDR=`LANG= LC_ALL= ifconfig ${DEVICE} | grep 'inet addr' |
-#                        awk -F: '{ print $2 } ' | awk '{ print $1 }'`
-#                /usr/local/sbin/ddns.py $IPADDR
-#        fi
+#	if [ "X${DEVICE}" == "Xeth0" ]; then
+#        	IPADDR=`LANG= LC_ALL= ifconfig ${DEVICE} | grep 'inet addr' |
+#                	awk -F: '{ print $2 } ' | awk '{ print $1 }'`
+#		/usr/local/sbin/ddns.py $IPADDR
+#	fi
 #
 # in /etc/ifup-local.
 #
@@ -35,15 +35,17 @@ import dns.tsigkeyring
 # Replace the keyname and secret with appropriate values for your
 # configuration.
 #
-keyring = dns.tsigkeyring.from_text({"keyname.": "NjHwPsMKjdN++dOfE5iAiQ=="})
+keyring = dns.tsigkeyring.from_text({
+    'keyname.' : 'NjHwPsMKjdN++dOfE5iAiQ=='
+    })
 
 #
 # Replace "example." with your domain, and "host" with your hostname.
 #
-update = dns.update.Update("example.", keyring=keyring)
-update.replace("host", 300, "A", sys.argv[1])
+update = dns.update.Update('example.', keyring=keyring)
+update.replace('host', 300, 'A', sys.argv[1])
 
 #
 # Replace "10.0.0.1" with the IP address of your master server.
 #
-response = dns.query.tcp(update, "10.0.0.1", timeout=10)
+response = dns.query.tcp(update, '10.0.0.1', timeout=10)
